..
   Copyright (C) 2011-2013 Jaakko Luttinen

   This file is licensed under the MIT License. See LICENSE for a text of the
   license.


.. _sec-user-api:

User API
========


.. autosummary::
    :toctree: generated/
    :template: autosummary/short_module.rst

    bayespy.nodes
    bayespy.inference
    bayespy.plot

